BackendAlertWaitResult class

Inheritance

Constructors

BackendAlertWaitResult({BackendAlertInfo? alert, int? waitedMs, bool? timedOut})
const

Properties

alert BackendAlertInfo?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timedOut bool?
final
waitedMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited