BackendMeasurePerfOptions class

Options for measuring performance.

Constructors

BackendMeasurePerfOptions({String? since, String? until, int? sampleMs, List<String>? metrics})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metrics List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleMs int?
final
since String?
final
until String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited