BackendMeasurePerfResult class

Result of measuring performance.

Constructors

BackendMeasurePerfResult({required List<BackendPerfMetric> metrics, String? startedAt, String? endedAt, String? backend, bool? redacted, List<String>? notes})
const

Properties

backend String?
final
endedAt String?
final
hashCode int
The hash code for this object.
no setterinherited
metrics List<BackendPerfMetric>
final
notes List<String>?
final
redacted bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited