BackendNetworkEntry class

A single network request/response entry.

Constructors

BackendNetworkEntry({String? timestamp, String? method, String? url, int? status, int? durationMs, Map<String, String>? requestHeaders, Map<String, String>? responseHeaders, String? requestBody, String? responseBody, Map<String, Object?>? metadata})
const

Properties

durationMs int?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, Object?>?
final
method String?
final
requestBody String?
final
requestHeaders Map<String, String>?
final
responseBody String?
final
responseHeaders Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
timestamp String?
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited