BackendReadLogsOptions class

Options for reading logs.

Constructors

BackendReadLogsOptions({String? cursor, int? limit, String? since, String? until, List<String>? levels, String? search, String? source})
const

Properties

cursor String?
final
hashCode int
The hash code for this object.
no setterinherited
levels List<String>?
final
limit int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
since String?
final
source String?
final
until String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited