ExecStreamOptions class
Options for streaming process execution.
- Inheritance
-
- Object
- ExecOptions
- ExecStreamOptions
Constructors
Properties
- allowFailure → bool
-
finalinherited
- binaryStdout → bool
-
finalinherited
- cwd → String?
-
finalinherited
- detached → bool
-
finalinherited
-
env
→ Map<
String, String> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- onSpawn → void Function(Process process)?
-
final
- onStderrChunk → void Function(String chunk)?
-
final
- onStdoutChunk → void Function(String chunk)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stdin → String?
-
finalinherited
- timeoutMs → int?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited