RetryAttemptContext class

Context information about a retry attempt.

Constructors

RetryAttemptContext({required int attempt, required int maxAttempts, Deadline? deadline})

Properties

attempt int
final
deadline Deadline?
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited