RetryPolicy class

Retry policy configuration.

Constructors

RetryPolicy({required int maxAttempts, required int baseDelayMs, required int maxDelayMs, required double jitter, bool shouldRetry(Object error, int attempt)?})

Properties

baseDelayMs int
final
hashCode int
The hash code for this object.
no setterinherited
jitter double
final
maxAttempts int
final
maxDelayMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRetry bool Function(Object error, int attempt)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited