RetryTelemetryEvent class

Telemetry event from a retry operation.

Constructors

RetryTelemetryEvent({String? phase, required String event, required int attempt, required int maxAttempts, int? delayMs, int? elapsedMs, int? remainingMs, String? reason})

Properties

attempt int
final
delayMs int?
final
elapsedMs int?
final
event String
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
phase String?
final
reason String?
final
remainingMs int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited