SnapshotNode class

Snapshot node with an attached reference string.

Constructors

SnapshotNode({required int index, required String ref, String? type, String? role, String? subrole, String? label, String? value, String? identifier, Rect? rect, bool? enabled, bool? selected, bool? hittable, int? depth, int? parentIndex, int? pid, String? bundleId, String? appName, String? windowTitle, String? surface, bool? hiddenContentAbove, bool? hiddenContentBelow})

Properties

appName String?
finalinherited
bundleId String?
finalinherited
depth int?
finalinherited
enabled bool?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hiddenContentAbove bool?
getter/setter pairinherited
hiddenContentBelow bool?
getter/setter pairinherited
hittable bool?
finalinherited
identifier String?
finalinherited
index int
finalinherited
label String?
finalinherited
parentIndex int?
finalinherited
pid int?
finalinherited
rect Rect?
finalinherited
ref String
final
role String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
finalinherited
subrole String?
finalinherited
surface String?
finalinherited
type String?
finalinherited
value String?
finalinherited
windowTitle String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited