BackendOpenOptions class
Options for opening an app.
Constructors
-
BackendOpenOptions({bool? relaunch, String? launchConsole, List<
String> ? launchArgs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
launchArgs
→ List<
String> ? -
Arguments forwarded verbatim to the app's launch. iOS: appended after the
bundle id on
simctl launch/devicectl process launch. Android: appended toam start(e.g.--es key valuefor typed Intent extras). An empty list launches with no extra args.final - launchConsole → String?
-
iOS simulator only: path to capture launch-time stdout/stderr from the
simctl launch --console-ptyinvocation. Not valid for URL opens or non-simulator targets.final - relaunch → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited