BackendReadLogsResult class
Result of reading logs.
Constructors
-
BackendReadLogsResult({required List<
BackendLogEntry> entries, String? nextCursor, BackendDiagnosticsTimeWindow? timeWindow, String? backend, bool? redacted, List<String> ? notes}) -
const
Properties
- backend → String?
-
final
-
entries
→ List<
BackendLogEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
final
-
notes
→ List<
String> ? -
final
- redacted → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeWindow → BackendDiagnosticsTimeWindow?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited